# AI Security Research Resources

## Langchain Resources
- [Tools, Learning, Notebooks, Bots, Agent examples, etc.](https://github.com/The-Art-of-Hacking/h4cker/blob/master/ai_research/LangChain/README.md)

## LLM Frameworks
- [Popular LLM Frameworks](https://github.com/The-Art-of-Hacking/h4cker/tree/master/ai_research/LLM-frameworks)

## Collection of Jupyter Notebooks
This is (by far) the best collection of colab notebooks I have found. A bit overwhelming and I wish I had time to go through most of them… Tons of links to papers, videos, etc.: https://github.com/amrzv/awesome-colab-notebooks
  
## AI Security Best Practices and Tools
- [High-Level AI Security Best Practices](<AI Security Best Practices/AI-security-tools-and-frameworks.md>)
- [Homomorphic-Encryption](<AI Security Best Practices/homomorphic-encryption.md>)
- [AI Security Tools and Frameworks](<AI Security Best Practices/AI-security-tools-and-frameworks.md>)
- [AI Secure Deployment Tips](<AI Security Best Practices/secure-deployment.md>)
- [AI Secure Design Tips](<AI Security Best Practices/secure-design.md>)
- [Threat Modeling](<AI Security Best Practices/threat-modeling.md>)

## AI Security Resources from Omar's Training Sessions
- [Cybersecurity Learning Prompts](https://github.com/santosomar/chatgpt-cybersecurity-prompts)
- [Networking Prompts](https://github.com/santosomar/chatgpt-networking-prompts)
- [Programming Learning Prompts](https://github.com/santosomar/chatgpt-programming-prompts)

## AI Ethics and Privacy Resources
- [AI Ethics and Privacy Resources](https://github.com/The-Art-of-Hacking/h4cker/tree/master/ai_research/ethics_privacy)

## AWESOME Lists
- [Awesome-LLM](https://github.com/Hannibal046/Awesome-LLM) - a huge collection of resources related to Gen AI and LLMs
- [Awesome ChatGPT Prompts](https://github.com/f/awesome-chatgpt-prompts) - A collection of prompt examples to be used with the ChatGPT model.
- [awesome-chatgpt-prompts-zh](https://github.com/PlexPt/awesome-chatgpt-prompts-zh) - A Chinese collection of prompt examples to be used with the ChatGPT model.
- [Awesome ChatGPT](https://github.com/humanloop/awesome-chatgpt) - Curated list of resources for ChatGPT and GPT-3 from OpenAI.
- [Chain-of-Thoughts Papers](https://github.com/Timothyxxx/Chain-of-ThoughtsPapers) -  A trend starts from "Chain of Thought Prompting Elicits Reasoning in Large Language Models.
- [Instruction-Tuning-Papers](https://github.com/SinclairCoder/Instruction-Tuning-Papers) - A trend starts from `Natrural-Instruction` (ACL 2022), `FLAN` (ICLR 2022) and `T0` (ICLR 2022).
- [LLM Reading List](https://github.com/crazyofapple/Reading_groups/) - A paper & resource list of large language models.
- [Reasoning using Language Models](https://github.com/atfortes/LM-Reasoning-Papers) - Collection of papers and resources on Reasoning using Language Models.
- [Chain-of-Thought Hub](https://github.com/FranxYao/chain-of-thought-hub) - Measuring LLMs' Reasoning Performance
- [Awesome GPT](https://github.com/formulahendry/awesome-gpt) - A curated list of awesome projects and resources related to GPT, ChatGPT, OpenAI, LLM, and more.
- [Awesome GPT-3](https://github.com/elyase/awesome-gpt3) - a collection of demos and articles about the [OpenAI GPT-3 API](https://openai.com/blog/openai-api/).
- [Awesome LLM Human Preference Datasets](https://github.com/PolisAI/awesome-llm-human-preference-datasets) - a collection of human preference datasets for LLM instruction tuning, RLHF and evaluation.
- [RWKV-howto](https://github.com/Hannibal046/RWKV-howto) - possibly useful materials and tutorial for learning RWKV.
- [ModelEditingPapers](https://github.com/zjunlp/ModelEditingPapers) - A paper & resource list on model editing for large language models.
- [Awesome LLM Security](https://github.com/corca-ai/awesome-llm-security) - A curation of awesome tools, documents and projects about LLM Security.
- [Awesome-Align-LLM-Human](https://github.com/GaryYufei/AlignLLMHumanSurvey) - A collection of papers and resources about aligning large language models (LLMs) with human.
- [Awesome-Code-LLM](https://github.com/huybery/Awesome-Code-LLM) - An awesome and curated list of best code-LLM for research.
- [Awesome-LLM-Compression](https://github.com/HuangOwen/Awesome-LLM-Compression) - Awesome LLM compression research papers and tools.
- [Awesome-LLM-Systems](https://github.com/AmberLJC/LLMSys-PaperList) - Awesome LLM systems research papers.
- [awesome-llm-webapps](https://github.com/snowfort-ai/awesome-llm-webapps) - A collection of open source, actively maintained web apps for LLM applications.
