# Basic Networking Resources

The following are some good basic networking resources to get you started.


## TCP/IP Protocols

**Note**: Links without description are official RFCs from the Internet Engineering Task Force (IETF).

* [Address Resolution Protocol (ARP)](https://datatracker.ietf.org/doc/rfc826/)
* [Border Gateway Protocol (BGP)](https://datatracker.ietf.org/doc/rfc4271/)
* [Domain Name System (DNS)](https://datatracker.ietf.org/doc/rfc1035/)
* [Dynamic Host Configuration Protocol (DHCP)](https://datatracker.ietf.org/doc/rfc2131/)
* [File Transfer Protocol (FTP)](https://datatracker.ietf.org/doc/rfc959/)
* [Hypertext Transfer Protocol (HTTP/1.1)](https://datatracker.ietf.org/doc/rfc2616/)
* [Hypertext Transfer Protocol Version 2 (HTTP/2)](https://datatracker.ietf.org/doc/rfc7540/)
* [Internet Protocol Version 4 (IPv4)](https://tools.ietf.org/html/rfc791/)
* [Internet Protocol Version 6 (IPv6)](https://datatracker.ietf.org/doc/rfc2460/)
* [Network Address Translator (NAT)](https://datatracker.ietf.org/doc/rfc1631/)
* [Simple Mail Transfer Protocol (SMTP)](https://datatracker.ietf.org/doc/rfc5321/)
* [Simple Network Management Protocol (SNMP)](https://datatracker.ietf.org/doc/rfc1157/)
* [Secure Shell (SSH)](https://datatracker.ietf.org/doc/rfc4251/)
* [Transmission Control Protocol (TCP)](https://datatracker.ietf.org/doc/rfc793/)
* [Telnet](https://datatracker.ietf.org/doc/rfc854/)
* [User Datagram Protocol (UDP)](https://datatracker.ietf.org/doc/rfc768/)

## Courses and YouTube Videos

* [Cisco Networking Academy Courses](https://www.netacad.com/courses/networking) - A various networking courses (Essentials, CCNA, CCNP, etc.).
* [Network Chuck OSI Model](https://www.youtube.com/watch?v=oIRkXulqJA4)
* [Network Chuck Subnetting Playlist](https://www.youtube.com/watch?v=5WfiTHiU4x8&list=PLIhvC56v63IKrRHh3gvZZBAGvsvOhwrRF)


## Tutorials

* [Networking](https://www.youtube.com/watch?v=rL8RSFQG8do&list=PLF360ED1082F6F2A5) - A series of YouTube tutorials about networking by Eli the Computer Guy.
* [Wireshark Tutorial for Beginners](https://www.youtube.com/watch?v=flDzURAm8wQ&list=PL6gx4Cwl9DGBI2ZFuyZOl5Q7sptR7PwYN) - TheNewBoston Wireshark Tutorial for Beginners.
* [MikroTik WinBox Manual](https://wiki.mikrotik.com/wiki/Manual:Winbox) - The official manual for MikroTik's WinBox software.

## Books
* [Cisco Press](https://www.ciscopress.com/) - Cisco authorized book publisher where you can get all books and official guides for Cisco certifications.
* [Practical Packet Analysis (3rd Edition)](https://nostarch.com/packetanalysis3) - An amazing book about analyzing network packets using Wireshark.
* [Attacking Network Protocols](https://nostarch.com/networkprotocols) - A Hacker's Guide to Capture, Analysis, and Exploitation
by James Forshaw.
* [Automate Your Network: Introducing the Modern Approach to Enterprise Network Management](https://www.amazon.com/Automate-Your-Network-Introducing-Enterprise/dp/1799237885) - Probably one of the best books for network automation by John W. Capobianco.

## Software and Tools

### Online tools

* [Online nslookup](https://www.nslookup.io) - An online DNS client to view and debug DNS configuration.
* [Online whois](https://whois.domaintools.com/) - An online whois record tool for getting information about domains.
* [OUI Lookup Tool](https://www.wireshark.org/tools/oui-lookup.html) - An online OUI lookup for searching vendors of MAC addresses.
* [MXToolbox](https://mxtoolbox.com/) - A large number of various tools (DNS lookup, MX lookup, Whois, SPF lookup, and more).

### Packet capture and analysis

**CHECKOUT THE Hacking Scenarios:** https://hackingscenarios.com

* [Wireshark](https://www.wireshark.org/) - The most popular free and open source network protocol analyzer.
* [Tshark](https://tshark.dev/) - A CLI version of Wireshark.
* [tcpdump](http://www.tcpdump.org/) - A powerful open source command-line packet analyzer.
* [NetworkMiner](https://www.netresec.com/?page=NetworkMiner) - A network forensic tool for PCAP file analysis.
* [Malware-Traffic-Analysis.net](https://malware-traffic-analysis.net/) - A large collection of malicious PCAP files that can be used to practice packet capture skills.
* [Publicly Available PCAP files](https://www.netresec.com/?page=PcapFiles) - A list of publicly available PCAP files for additional training.

### Network simulators and emulators

* [GNS3](https://gns3.com/) - A powerful free and open source network simulator.
* [Cisco Packet Tracer](https://www.netacad.com/courses/packet-tracer) - Cross-platform network visual simulation tool designed by Cisco Systems.
* [EVE-NG](https://www.eve-ng.net/) - A powerful network simulator. Both Community and Professional editions are available.
* [Cisco Modeling Labs](https://www.cisco.com/c/en/us/products/cloud-systems-management/modeling-labs/index.html) - An online platform that helps network engineers simulate the behavior of Cisco routers, switches, and access points. It is intended for customers from enterprise backgrounds.
* [Cisco Virtual Internet Routing Lab (VIRL)](https://learningnetwork.cisco.com/s/virl) - It is a Cisco IOS-based comprehensive network simulation environment. It is intended for all individuals and trainees.

### Firewalls and switches

* [pfSense](https://www.pfsense.org/) - An open source firewall/router computer software distribution based on FreeBSD.
* [OPNsense](https://opnsense.org/) - OPNsense is an open source, easy-to-use, and easy-to-build FreeBSD based firewall and routing platform.
* [Open vSwitch](https://www.openvswitch.org/) - Open vSwitch is a production quality, multilayer virtual switch licensed under the open source Apache 2.0 license.

### Remote access and sharing tools

* [Remmina](https://remmina.org/) - An open source remote access tool. It supports RDP, SSH, VNC, and other protocols for remote access.
* [PuTTY](https://www.putty.org/) - One of the most popular SSH and Telnet clients for Windows.
* [FileZilla](https://filezilla-project.org/) - An open source tool for file transfer. Support FTP, FTPS and SFTP protocols.
* [WinSCP](https://winscp.net/eng/index.php) - A popular SFTP client and FTP client for Windows.
* [SecureCRT](https://www.vandyke.com/products/securecrt/) - A commercial SSH and Telnet client and terminal emulator by VanDyke Software.
* [WinBox](https://mikrotik.com/download) - Official MikroTik GUI software for administration of MikroTik RouterOS.

### Other tools

* [Nmap](https://nmap.org/) - A free and open source software for network discovery and security auditing.
* [Zenmap](https://nmap.org/zenmap/) - The official Nmap Security Scanner GUI.
* [Draw.io](https://github.com/jgraph/drawio-desktop) - An open source software for creating network diagrams and topologies.

## Certifications

* [Cisco certifications](https://www.cisco.com/c/en/us/training-events/training-certifications/certifications.html)
